Structs

A immutable entry of an entity in an ArchetypeStorage. Provides convenient and faster access to entity components.
A mutable entry of an entity in an ArchetypeStorage. Provides convenient and faster access to entity components.