pub struct SystemAccess<'a> { /* private fields */ }
Represents all available components to a system.

Implementations

source

impl<'a> SystemAccess<'a>

source

pub fn type_id_to_archetype_id(&self, type_id: &TypeId) -> Option<ArchetypeId>

Returns ArchetypeId corresponding to the specified TypeId.

source

pub fn component<C: Component>(&self) -> GlobalComponentAccess<'_, C>

Borrows the component. Panics if the component is mutably borrowed or not available to this system.

source

pub fn component_mut<'b, C: Component>( &'b self ) -> GlobalComponentAccessMut<'a, 'b, C>

Mutably borrows the component. Panics if the component is already borrowed or not available to this system.