Struct entity_data::EntityStorage [−][src]
pub struct EntityStorage { /* fields omitted */ }Expand description
A container of entities.
Implementations
Creates an empty EntityStorage.
Returns EntityBuilder of the new entity.
Returns a reference to the specified archetype.
Returns a mutable reference to the specified archetype.
Returns a reference to the component C of the specified entity.
Returns a mutable reference to the component C of the specified entity.
Removes an entity from the storage. Returns true if the entity was present in the storage.